==> pan-0.11.4.tar.gz: pan-0.11.4/pan/message-check-ui.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 2000, 2001  Pan Development Team <pan@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __MESSAGE_CHECK_UI_H__
#define __MESSAGE_CHECK_UI_H__

#include <glib.h>
#include <pan/base/message-check.h>
#include <gtk/gtkwindow.h>

typedef void (*ArticleCheckedFunc)(Server          * server,
                                   Article         * article,
                                   GoodnessLevel     goodness,
                                   gpointer          user_data);

void check_article_and_prompt (GtkWidget           * window,
                               Server              * server_to_post_article,
                               Article             * article_to_post,
                               ArticleCheckedFunc    checked_func,
                               gpointer              checked_func_user_data);

#endif

==> pan-0.11.91.tar.gz: pan-0.11.91/pan/message-check-ui.h <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 2000, 2001  Pan Development Team <pan@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#ifndef __MESSAGE_CHECK_UI_H__
#define __MESSAGE_CHECK_UI_H__

#include <glib.h>
#include <pan/base/message-check.h>
#include <gtk/gtkwidget.h>

typedef void (*ArticleCheckedFunc)(Server          * server,
                                   Article         * article,
                                   GoodnessLevel     goodness,
                                   gpointer          user_data);

void check_article_and_prompt (GtkWidget           * window,
                               Server              * server_to_post_article,
                               Article             * article_to_post,
                               ArticleCheckedFunc    checked_func,
                               gpointer              checked_func_user_data);

#endif
